<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="fr_FR">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../prelevement.ui" line="61"/>
        <source>Concentration (mol/L)</source>
        <translation>Concentration (mol/L)</translation>
    </message>
    <message>
        <location filename="../prelevement.ui" line="68"/>
        <source>0.1</source>
        <translation>0.1</translation>
    </message>
    <message>
        <location filename="../prelevement.ui" line="75"/>
        <source>Volume (mL)</source>
        <translation>Volume (mL)</translation>
    </message>
    <message>
        <location filename="../prelevement.ui" line="82"/>
        <source>10.0</source>
        <translation>10.0</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../prelevement.ui" line="14"/>
        <source>Définition d&apos;un prélèvement</source>
        <translation>Define a sample</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../prelevement.ui" line="45"/>
        <source>Prélèvement : </source>
        <translation>Sample:</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../curvecontrol.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../curvecontrol.ui" line="50"/>
        <source>Cliquer pour afficher/cacher la courbe</source>
        <translation>Click to show/hide the plot</translation>
    </message>
    <message>
        <location filename="../curvecontrol.ui" line="106"/>
        <source>cliquer pour changer la couleur de la courbe</source>
        <translation>Click to change the color of the plot</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="71"/>
        <source>Laboratoire</source>
        <translation>Laboratory</translation>
    </message>
    <message>
        <location filename="../main.ui" line="186"/>
        <source>Burette</source>
        <translation>Burette</translation>
    </message>
    <message>
        <location filename="../main.ui" line="664"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="724"/>
        <source>toolBar</source>
        <translation>toolBar</translation>
    </message>
    <message>
        <location filename="../main.ui" line="787"/>
        <source>pH</source>
        <translation>pH</translation>
    </message>
    <message>
        <location filename="../main.ui" line="26"/>
        <source>pyAcidoBasic</source>
        <translation>pyAcidoBasic</translation>
    </message>
    <message>
        <location filename="../main.ui" line="579"/>
        <source>exporter au format PDF</source>
        <translation>export in PDF format</translation>
    </message>
    <message>
        <location filename="../main.ui" line="596"/>
        <source>exporter au format JPEG</source>
        <translation>export in JPEG format</translation>
    </message>
    <message>
        <location filename="../main.ui" line="613"/>
        <source>exporter au format SVG</source>
        <translation>export in SVG format</translation>
    </message>
    <message>
        <location filename="../main.ui" line="644"/>
        <source>augmenter l&apos;intervalle des abscisses</source>
        <translation>make the abscissa range wider</translation>
    </message>
    <message>
        <location filename="../main.ui" line="661"/>
        <source>diminuer l&apos;intervalle des abscisses</source>
        <translation>make the abscissa range narrower</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Concentrations</source>
        <translation>Concentrations</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Fichier</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../main.ui" line="707"/>
        <source>&amp;Aide</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../main.ui" line="736"/>
        <source>&amp;Ouvrir ... (Ctrl-O)</source>
        <translation>&amp;Open ... (Ctrl-O)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="744"/>
        <source>Enregi&amp;strer ... (Ctrl-S)</source>
        <translation>&amp;Save ... (Ctrl-S)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="752"/>
        <source>Enregistrer Sous ... (Maj Ctrl -S)</source>
        <translation>Save as ... (Shift-Ctrl-S)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="757"/>
        <source>&amp;Quitter (Ctrl-Q)</source>
        <translation>&amp;Quit (Ctrl-Q)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="770"/>
        <source>&amp;Manuel (F1)</source>
        <translation>&amp;Manual (F1)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="803"/>
        <source>[H3O+]</source>
        <translation>[H3O+]</translation>
    </message>
    <message>
        <location filename="../main.ui" line="811"/>
        <source>[HO-]</source>
        <translation>[HO-]</translation>
    </message>
    <message>
        <location filename="../main.ui" line="816"/>
        <source>Autres ... (Ctrl-T)</source>
        <translation>Others... (Ctrl-T)</translation>
    </message>
    <message>
        <location filename="../main.ui" line="824"/>
        <source>Exemples ...</source>
        <translation>Examples...</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="101"/>
        <source>Choix des réactifs</source>
        <translation>Choose reagents</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="152"/>
        <source>Choisr un réactif et le tirer vers la burette ou le bécher</source>
        <translation>Choose a reagent and drag it to the burette or the beaker</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="155"/>
        <source>Liste des réactifs : Tirer un réactif vers la burette ou vers le bécher.</source>
        <translation>List of reagents: drag a reagent to the burette or the beaker.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="198"/>
        <source>vider la burette pour la remplir à nouveau</source>
        <translation>drain the burette to fill it again</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="227"/>
        <source>tirer un réactif vers la burette</source>
        <translation>drag a reagent to the burette</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="230"/>
        <source>Réactif de la burette : tirer un réactif depuis la liste ci-dessus.</source>
        <translation>Reagent of the burette: drag a reagent from the above list.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="246"/>
        <source>Bécher</source>
        <translation>Beaker</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="255"/>
        <source>vider le bécher pour la remplir à nouveau</source>
        <translation>drain the beaker to fill it again</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="284"/>
        <source>tirer un ou plusieurs réactifs vers le bécher</source>
        <translation>drag one or more reagents to the beaker</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="287"/>
        <source>Liste des réactifs du bécher : tirer des réactifs de la liste ci-dessus.</source>
        <translation>List of reagents of the beaker: drag the reagents from the above list.</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="630"/>
        <source>Définir le titre</source>
        <translation>Define the title</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="471"/>
        <source>Courbes à tracer</source>
        <translation>Curves to plot</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="765"/>
        <source>À &amp;propos ...</source>
        <translation>&amp;About...</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="795"/>
        <source>dérivée</source>
        <translation>derivative</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="122"/>
        <source>Filtre :</source>
        <translation>Filter:</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="110"/>
        <source>Taper quelques lettres du réactif pour le sélectionner plus facilement</source>
        <translation>Type in a few charcters of the reagent</translation>
    </message>
    <message>
        <location filename="../main.ui" line="135"/>
        <source>Cliquer pour effacer le filtre</source>
        <translation>Click to delete the filter</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="451"/>
        <source>Concentrations/Quantités</source>
        <translation>Concentrations/Quantities</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="508"/>
        <source>Quantités</source>
        <translation>Quantities</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../main.ui" line="486"/>
        <source>Choisir le type de représentation</source>
        <translation>Choose the type of plot</translation>
    </message>
</context>
<context>
    <name>pyacidobasic</name>
    <message>
        <location filename="../__init__.py" line="287"/>
        <source>Fichier pour enregistrer</source>
        <translation>File to save</translation>
    </message>
    <message>
        <location filename="../__init__.py" line="287"/>
        <source>Fichiers Acidobasic [*.acb] (*.acb);; Tous types de fichiers (*.* *)</source>
        <translation>Acidobasic files [*.acb] (*.acb);; All files (*.* *)</translation>
    </message>
    <message>
        <location filename="../__init__.py" line="299"/>
        <source>Erreur de version</source>
        <translation>Version error</translation>
    </message>
    <message>
        <location filename="../__init__.py" line="371"/>
        <source>Courbe du dosage</source>
        <translation>Titration plot</translation>
    </message>
    <message>
        <location filename="../__init__.py" line="299"/>
        <source>Ce fichier n&apos;est pas un fichier Pyacidobasic valide, de version %1.</source>
        <translation>This file is not a valid Pyacidobasic file (version %1).</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../__init__.py" line="311"/>
        <source>À propos</source>
        <translation>About</translation>
    </message>
</context>
</TS>
